# Rare
## A frontend for legendary, the open source Epic Games Launcher alternative

Rare is currently considered beta software and in no way feature-complete. You **will** run into issues, so make backups first!

### Requirements
 - requests, 
 - pillow
 - pyqt5
 - legendary-gl
 - PyQtWebengine


 
### Simple Windows Windows
Download Rare.exe and place it somewhere in PATH

### Linux
- For Arch Linux is an AUR package available [rare-git](https://aur.archlinux.org/rare-git.git)
- 

 ### Implemented
- Launch, install and uninstall games
- Authentication(Import from existing installation and via Browser)**(Please test it!)**
- In-app Browser to buy games
- Settings
### Todos
- Sync saves
- ...


### Images

![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/GameList.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/Uninstalled.png?raw=true)
![alt text](https://github.com/Dummerle/Rare/blob/master/Screenshots/Settings.png?raw=true)



If you have features you want to have in this app, create an issue on github or build it yourself. Please report bugs(Especially Windows)

